@@ -14,6 +14,7 @@ import (
 	"strconv"
 	"strings"
 	"sync"
+	"syscall"
 	"time"
 
 	"github.com/google/go-cmp/cmp"
@@ -46,6 +47,7 @@ type IntelRDT struct {
 	Processes        []string `toml:"processes"`
 	SamplingInterval int32    `toml:"sampling_interval"`
 	ShortenedMetrics bool     `toml:"shortened_metrics"`
+	UseSudo          bool     `toml:"use_sudo"`
 
 	Log              telegraf.Logger  `toml:"-"`
 	Publisher        Publisher        `toml:"-"`
@@ -64,6 +66,12 @@ type processMeasurement struct {
 	measurement string
 }
 
+type splitCSVLine struct {
+	timeValue        string
+	metricsValues    []string
+	coreOrPIDsValues []string
+}
+
 // All gathering is done in the Start function
 func (r *IntelRDT) Gather(_ telegraf.Accumulator) error {
 	return nil
@@ -97,6 +105,10 @@ func (r *IntelRDT) SampleConfig() string {
 	## Mandatory if cores aren't set and forbidden if cores are specified.
 	## e.g. ["qemu", "pmd"]
 	# processes = ["process"]
+
+	## Specify if the pqos process should be called with sudo.
+	## Mandatory if the telegraf process does not run as root.
+	# use_sudo = false
 `
 }
 
@@ -224,8 +236,8 @@ func (r *IntelRDT) associateProcessesWithPIDs(providedProcesses []string) (map[s
 	}
 	for _, availableProcess := range availableProcesses {
 		if choice.Contains(availableProcess.Name, providedProcesses) {
-			PID := availableProcess.PID
-			mapProcessPIDs[availableProcess.Name] = mapProcessPIDs[availableProcess.Name] + fmt.Sprintf("%d", PID) + ","
+			pid := availableProcess.PID
+			mapProcessPIDs[availableProcess.Name] = mapProcessPIDs[availableProcess.Name] + fmt.Sprintf("%d", pid) + ","
 		}
 	}
 	for key := range mapProcessPIDs {
@@ -252,7 +264,13 @@ func (r *IntelRDT) readData(ctx context.Context, args []string, processesPIDsAss
 	r.wg.Add(1)
 	defer r.wg.Done()
 
-	cmd := exec.Command(r.PqosPath, append(args)...)
+	cmd := exec.Command(r.PqosPath, args...)
+
+	if r.UseSudo {
+		// run pqos with `/bin/sh -c "sudo /path/to/pqos ..."`
+		args = []string{"-c", fmt.Sprintf("sudo %s %s", r.PqosPath, strings.Replace(strings.Join(args, " "), ";", "\\;", -1))}
+		cmd = exec.Command("/bin/sh", args...)
+	}
 
 	cmdReader, err := cmd.StdoutPipe()
 	if err != nil {
@@ -315,13 +333,13 @@ func (r *IntelRDT) processOutput(cmdReader io.ReadCloser, processesPIDsAssociati
 		if len(r.Processes) != 0 {
 			newMetric := processMeasurement{}
 
-			PIDs, err := findPIDsInMeasurement(out)
+			pids, err := findPIDsInMeasurement(out)
 			if err != nil {
 				r.errorChan <- err
 				break
 			}
 			for processName, PIDsProcess := range processesPIDsAssociation {
-				if PIDs == PIDsProcess {
+				if pids == PIDsProcess {
 					newMetric.name = processName
 					newMetric.measurement = out
 				}
@@ -334,14 +352,30 @@ func (r *IntelRDT) processOutput(cmdReader io.ReadCloser, processesPIDsAssociati
 }
 
 func shutDownPqos(pqos *exec.Cmd) error {
+	timeout := time.Second * 2
+
 	if pqos.Process != nil {
-		err := pqos.Process.Signal(os.Interrupt)
-		if err != nil {
-			err = pqos.Process.Kill()
-			if err != nil {
-				return fmt.Errorf("failed to shut down pqos: %v", err)
+		// try to send interrupt signal, ignore err for now
+		_ = pqos.Process.Signal(os.Interrupt)
+
+		// wait and constantly check if pqos is still running
+		ctx, cancel := context.WithTimeout(context.Background(), timeout)
+		defer cancel()
+		for {
+			if err := pqos.Process.Signal(syscall.Signal(0)); err == os.ErrProcessDone {
+				return nil
+			} else if ctx.Err() != nil {
+				break
 			}
 		}
+
+		// if pqos is still running after some period, try to kill it
+		// this will send SIGTERM to pqos, and leave garbage in `/sys/fs/resctrl/mon_groups`
+		// fixed in https://github.com/intel/intel-cmt-cat/issues/197
+		err := pqos.Process.Kill()
+		if err != nil {
+			return fmt.Errorf("failed to shut down pqos: %v", err)
+		}
 	}
 	return nil
 }
@@ -454,29 +488,29 @@ func validateAndParseCores(coreStr string) ([]int, error) {
 func findPIDsInMeasurement(measurements string) (string, error) {
 	// to distinguish PIDs from Cores (PIDs should be in quotes)
 	var insideQuoteRegex = regexp.MustCompile(`"(.*?)"`)
-	PIDsMatch := insideQuoteRegex.FindStringSubmatch(measurements)
-	if len(PIDsMatch) < 2 {
+	pidsMatch := insideQuoteRegex.FindStringSubmatch(measurements)
+	if len(pidsMatch) < 2 {
 		return "", fmt.Errorf("cannot find PIDs in measurement line")
 	}
-	PIDs := PIDsMatch[1]
-	return PIDs, nil
+	pids := pidsMatch[1]
+	return pids, nil
 }
 
-func splitCSVLineIntoValues(line string) (timeValue string, metricsValues, coreOrPIDsValues []string, err error) {
+func splitCSVLineIntoValues(line string) (splitCSVLine, error) {
 	values, err := splitMeasurementLine(line)
 	if err != nil {
-		return "", nil, nil, err
+		return splitCSVLine{}, err
 	}
 
-	timeValue = values[0]
+	timeValue := values[0]
 	// Because pqos csv format is broken when many cores are involved in PID or
 	// group of PIDs, there is need to work around it. E.g.:
 	// Time,PID,Core,IPC,LLC Misses,LLC[KB],MBL[MB/s],MBR[MB/s],MBT[MB/s]
 	// 2020-08-12 13:34:36,"45417,29170,",37,44,0.00,0,0.0,0.0,0.0,0.0
-	metricsValues = values[len(values)-numberOfMetrics:]
-	coreOrPIDsValues = values[1 : len(values)-numberOfMetrics]
+	metricsValues := values[len(values)-numberOfMetrics:]
+	coreOrPIDsValues := values[1 : len(values)-numberOfMetrics]
 
-	return timeValue, metricsValues, coreOrPIDsValues, nil
+	return splitCSVLine{timeValue, metricsValues, coreOrPIDsValues}, nil
 }
 
 func validateInterval(interval int32) error {
@@ -495,7 +529,7 @@ func splitMeasurementLine(line string) ([]string, error) {
 }
 
 func parseTime(value string) (time.Time, error) {
-	timestamp, err := time.Parse(timestampFormat, value)
+	timestamp, err := time.ParseInLocation(timestampFormat, value, time.Local)
 	if err != nil {
 		return time.Time{}, err
 	}
